==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedPrintRequestAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class 7b26d2cbddd7a4b4 javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$method$_init$0ca123b9de7369cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedPrintRequestAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class 7b26d2cbddd7a4b4 javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$method$_init$0ca123b9de7369cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintRequestAttributeSet_H_ */
